.. calcos documentation master file, created by
   sphinx-quickstart on Mon Sep 27 15:35:19 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to calcos's documentation!
==================================

Please see https://hst-docs.stsci.edu/cosdhb/chapter-3-cos-calibration .
